R/delete_comment.R
delete_comment.Rd
Delete a comment on a jira ticket
delete_comment(id, issue = NULL)
the ID of the comment
the issue key. Defaults to the project directory base name, assuming the R project is named after the issue key.
Derek Chiu