Skip to contents

Returns the user designated as the assignee for an issue

Usage

get_issue_assignee(issue = NULL)

Arguments

issue

the issue key. Defaults to the project directory base name, assuming the R project is named after the issue key.

Author

Derek Chiu