Skip to contents

Returns the user who created the issue

Usage

get_issue_reporter(issue = NULL)

Arguments

issue

the issue key. Defaults to the project directory base name, assuming the R project is named after the issue key.

Author

Derek Chiu