R/get_issue_assignee.R
get_issue_assignee.Rd
Returns the user designated as the assignee for an issue
get_issue_assignee(issue = NULL)
the issue key. Defaults to the project directory base name, assuming the R project is named after the issue key.
Derek Chiu