R/get_issue_reporter.R
get_issue_reporter.Rd
Returns the user who created the issue
get_issue_reporter(issue = NULL)
the issue key. Defaults to the project directory base name, assuming the R project is named after the issue key.
Derek Chiu